.. _about

=============
About docubox
=============

DocuBox - The swiss army knife for document solution powered by Python.

Copyright (C) 2022,2023 Hiroshi Miura

First release in 3, January, 2023

DocuBox is a single binary utility that have several document solution commands.
When it is called as sphinx-build_, it behave as ``sphinx``.
When it is called as mkdocs_, it behave as ``mkdocs``.

Please symbolic link to the name you want.

Supported features

- sphinx-quickstart_
- sphinx-build_
- sphinx-intl_
- mkdocs_
- pybabel_
- markdown_it
- j2cli
- jsonschema
- m2r_
- myst-anchors
- myst-docutils-html
- myst-docutils-html5
- myst-docutils-xml
- myst-docutils-pseudoxml
- myst-docutils-latex
- pygmentize

.. _sphinx-quickstart: https://www.sphinx-doc.org/en/master/usage/quickstart.html
.. _sphinx-build: https://www.sphinx-doc.org/en/master/man/sphinx-build.html
.. _sphinx-intl: https://sphinx-intl.readthedocs.io/en/master/
.. _mkdocs: https://www.mkdocs.org/
.. _pybabel: https://babel.pocoo.org/en/latest/cmdline.html
.. _m2r: https://pypi.org/project/m2r/

.. _installation:

Install docubox binary
======================

Download from the download portal.

* Download binary: https://codeberg.org/miurahr/docubox/releases


Install from source
===================

Requirements
------------

- Minimum Python version:  3.11


Install by pip command
----------------------

Same as usual, it can be installed with ``pip``
You are strongly recommended to install into venv/virtualenv
for working.

.. code-block:: bash

    $ pip install venv
    $ python3 -m venv venv
    $ source ./venv/bin/activate
    (venv)$ pip install docubox


Install by git command
----------------------

You can install docubox from source

.. code-block:: bash

   $ git clone https://codeberg.org/miurahr/docubox.git
   $ cd docubox
   $ python3 -m venv venv
   $ source ./venv/bin/activate
   (venv)$ pip install .


.. _generation

Generate docubox binary
=======================

A binary executable can be generated by command

.. code-block:: bash

   $ source ./venv/bin/activate
   (venv)$ python -m docubox

When you want to generate all the known commands as link, please use '-l' or '--link' option,

.. code-block:: bash

   $ source ./venv/bin/activate
   (venv)$ python -m docubox --link

When you want to specify a binary name use '-n' or '--name' argument option;

.. code-block:: bash

   $ source ./venv/bin/activate
   (venv)$ python -m docubox -n sphinx-build

If you run on Windows platform, docubox automatically add ".exe" file extension name.

When you want to generate hash files, docubox.sha256 and docubox.sha512, please add an option,

.. code-block:: bash

   $ source ./venv/bin/activate
   (venv)$ python -m docubox --sha


Binaries are generated in ``dist/`` folder.

